/******************************************************************************
 * Author: Owen Lin
 * File: K4Board.h
 * Last Modified: 7-8-97
 * Description: This is the definition of the K4Board. More detailed 
 *              descriptions of the functions can be found in the 
 *              implementation file, K4Board.c. K4Board provides a data type
 *              as well as a set of operations for that data type.
 ******************************************************************************
 */
#ifndef K4BOARD_H
#define K4BOARD_H

/* turn is basically a boolean that stores the current turn */
int turn;

/* This is the board structure */
struct K4Board {
  int chips;                /* the total number of chips remaining */
  int game_board[8][7];     /* the board, an array used as an adjacency list */
  int win_valid[2][69];     /* boolean array used to tell if win is possible in
			       that position that player */
  int chips_in_column[8];   /* number of chips in the column */
  int changes_length;       /* the length of the last changes array */
  int last_changes[69];     /* used to store the last changes made to win_valid
			       for a the last move */
};

struct K4Board main_board; /* define the main game board used during the game*/
int win_positions[69][4];  /* stores the winning positions */

/* See the implementation for information on these functions */
void InitGame();
void ToggleTurn();
int IsDraw(const struct K4Board* board);
int IsColumnFull(int column,const struct K4Board* board); 
int ColumnHeight(int column, const struct K4Board* board);
void CopyK4Board(struct K4Board* new_board, 
		 const struct K4Board* board_to_copy);
void PutChip(int player, int column, struct K4Board* board);
void RemoveChip(int column, struct K4Board* board);
void Winner(int player, int result[], const struct K4Board* board);
void MarkPosition(int player, int column, struct K4Board* board);
void DFSMove(int player, int depth, float floor, int* result,
	     const struct K4Board* board);
int DFSMove2(int player, int depth, const struct K4Board* board);
int DFSMove2Aux(int player, int depth, int alpha, int beta,
	    const struct K4Board* board);

#endif
